@@ -278,6 +278,49 @@ webkit_pref_callback_font_family (GConfClient *client,
   }
 }
 
+/* Part of this code taken from libsoup (soup-session.c) */
+static gchar *
+build_accept_languages_header (GArray *languages)
+{
+  gchar **langs = NULL;
+  gchar *langs_str = NULL;
+  gint delta;
+  gint i;
+
+  g_return_val_if_fail (languages != NULL, NULL);
+
+  /* Calculate deltas for the quality values */
+  if (languages->len < 10)
+    delta = 10;
+  else if (languages->len < 20)
+    delta = 5;
+  else
+    delta = 1;
+
+  /* Set quality values for each language */
+  langs = (gchar **) languages->data;
+  for (i = 0; langs[i] != NULL; i++) {
+    gchar *lang = (gchar *) langs[i];
+    gint quality = 100 - i * delta;
+
+    if (quality > 0 && quality < 100) {
+      gchar buf[8];
+      g_ascii_formatd (buf, 8, "%.2f", quality/100.0);
+      langs[i] = g_strdup_printf ("%s;q=%s", lang, buf);
+    } else {
+      /* Just dup the string in this case */
+      langs[i] = g_strdup (lang);
+    }
+    g_free (lang);
+  }
+
+  /* Get the result string */
+  if (languages->len > 0)
+    langs_str = g_strjoinv (", ", langs);
+
+  return langs_str;
+}
+
 /* Based on Christian Persch's code from gecko backend of epiphany
    (old transform_accept_languages_list() function) */
 static void
@@ -290,7 +333,7 @@ webkit_pref_callback_accept_languages (GConfClient *client,
   GConfValue *gcvalue;
   GArray *array;
   GSList *languages, *l;
-  char **langs;
+  char **array_data;
   char *langs_str;
   char *webkit_pref;
 
@@ -318,17 +361,74 @@ webkit_pref_callback_accept_languages (GConfClient *client,
 
   ephy_langs_sanitise (array);
 
-  langs = (char **) g_array_free (array, FALSE);
-  langs_str = g_strjoinv (", ", langs);
+  langs_str = build_accept_languages_header (array);
 
   /* Update Soup session */
   session = webkit_get_default_session ();
   g_object_set (G_OBJECT (session), webkit_pref, langs_str, NULL);
 
-  g_strfreev (langs);
+  /* Free memory */
+  array_data = (char **) g_array_free (array, FALSE);
+  g_strfreev (array_data);
   g_free (langs_str);
 }
 
+void
+ephy_embed_prefs_set_cookie_jar_policy (SoupCookieJar *jar,
+                                        const char *gconf_policy)
+{
+  SoupCookieJarAcceptPolicy policy;
+
+  g_return_if_fail (SOUP_IS_COOKIE_JAR (jar));
+  g_return_if_fail (gconf_policy != NULL);
+
+  if (g_str_equal (gconf_policy, "nowhere"))
+    policy = SOUP_COOKIE_JAR_ACCEPT_NEVER;
+  else if (g_str_equal (gconf_policy, "anywhere"))
+    policy = SOUP_COOKIE_JAR_ACCEPT_ALWAYS;
+  else if (g_str_equal (gconf_policy, "current site"))
+    policy = SOUP_COOKIE_JAR_ACCEPT_NO_THIRD_PARTY;
+  else {
+    g_warn_if_reached ();
+    return;
+  }
+
+  g_object_set (G_OBJECT (jar), SOUP_COOKIE_JAR_ACCEPT_POLICY, policy, NULL);
+}
+
+static void
+webkit_pref_callback_cookie_accept_policy (GConfClient *client,
+                                           guint cnxn_id,
+                                           GConfEntry *entry,
+                                           gpointer data)
+{
+  SoupSession *session;
+  char *webkit_pref;
+  GConfValue *gcvalue;
+  const char *value = NULL;
+
+  webkit_pref = data;
+
+  gcvalue = gconf_entry_get_value (entry);
+
+  /* happens on initial notify if the key doesn't exist */
+  if (gcvalue != NULL &&
+      gcvalue->type == GCONF_VALUE_STRING) {
+      value = gconf_value_get_string (gcvalue);
+  }
+
+  if (value) {
+    SoupSessionFeature *jar;
+
+    session = webkit_get_default_session ();
+    jar = soup_session_get_feature (session, SOUP_TYPE_COOKIE_JAR);
+    if (!jar)
+      return;
+    
+    ephy_embed_prefs_set_cookie_jar_policy (SOUP_COOKIE_JAR (jar), value);
+  }
+}
+
 static const PrefData webkit_pref_entries[] =
   {
     { CONF_RENDERING_FONT_MIN_SIZE,
@@ -372,7 +472,13 @@ static const PrefData webkit_pref_entries[] =
       webkit_pref_callback_accept_languages },
     { CONF_USER_AGENT,
       "user-agent",
-      webkit_pref_callback_user_agent }
+      webkit_pref_callback_user_agent },
+    { CONF_SECURITY_COOKIES_ACCEPT,
+      "accept-policy",
+      webkit_pref_callback_cookie_accept_policy },
+    { CONF_SECURITY_PLUGINS_ENABLED,
+      "enable-plugins",
+      webkit_pref_callback_boolean }
   };
 
 static void
@@ -397,6 +503,7 @@ ephy_embed_prefs_init (void)
                 "enable-default-context-menu", FALSE,
                 "enable-site-specific-quirks", TRUE,
                 "enable-page-cache", TRUE,
+                "auto-resize-window", TRUE,
                 NULL);
 
   /* Connections */
