@@ -49,9 +49,13 @@
 #include <string.h>
 #include <webkit/webkit.h>
 
-static void     ephy_embed_class_init  (EphyEmbedClass *klass);
-static void     ephy_embed_init        (EphyEmbed *gs);
-static void     ephy_embed_constructed (GObject *object);
+static void     ephy_embed_class_init       (EphyEmbedClass *klass);
+static void     ephy_embed_init             (EphyEmbed *gs);
+static void     ephy_embed_constructed      (GObject *object);
+static gboolean ephy_embed_inspect_show_cb  (WebKitWebInspector *inspector,
+                                             EphyEmbed *embed);
+static gboolean ephy_embed_inspect_close_cb (WebKitWebInspector *inspector,
+                                             EphyEmbed *embed);
 
 #define EPHY_EMBED_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED, EphyEmbedPrivate))
 
@@ -59,10 +63,13 @@ struct EphyEmbedPrivate
 {
   GtkBox *top_widgets_vbox;
   GtkScrolledWindow *scrolled_window;
+  GtkPaned *paned;
   WebKitWebView *web_view;
   EphyHistory *history;
   GtkWidget *inspector_window;
   char *loading_uri;
+  GtkWidget *inspector_scrolled_window;
+  gboolean inspector_attached;
   guint is_setting_zoom : 1;
   GSList *destroy_on_transition_list;
 };
@@ -352,6 +359,32 @@ ephy_embed_grab_focus (GtkWidget *widget)
     gtk_widget_grab_focus (child);
 }
 
+static void
+ephy_embed_dispose (GObject *object)
+{
+  EphyEmbed *embed = EPHY_EMBED (object);
+
+  if (embed->priv->inspector_window)
+  {
+    WebKitWebInspector *inspector;
+
+    inspector = webkit_web_view_get_inspector (embed->priv->web_view);
+
+    g_signal_handlers_disconnect_by_func (inspector,
+                                          ephy_embed_inspect_show_cb,
+                                          embed->priv->inspector_window);
+
+    g_signal_handlers_disconnect_by_func (inspector,
+                                          ephy_embed_inspect_close_cb,
+                                          embed->priv->inspector_window);
+
+    gtk_widget_destroy (GTK_WIDGET (embed->priv->inspector_window));
+    embed->priv->inspector_window = NULL;
+  }
+
+  G_OBJECT_CLASS (ephy_embed_parent_class)->dispose (object);
+}
+
 static void
 ephy_embed_finalize (GObject *object)
 {
@@ -382,6 +415,7 @@ ephy_embed_class_init (EphyEmbedClass *klass)
 
   object_class->constructed = ephy_embed_constructed;
   object_class->finalize = ephy_embed_finalize;
+  object_class->dispose = ephy_embed_dispose;
   widget_class->grab_focus = ephy_embed_grab_focus;
 
   g_type_class_add_private (G_OBJECT_CLASS (klass), sizeof(EphyEmbedPrivate));
@@ -404,18 +438,94 @@ ephy_embed_inspect_web_view_cb (WebKitWebInspector *inspector,
 }
 
 static gboolean
-ephy_embed_inspect_show_cb (WebKitWebInspector *inspector,
-                              GtkWidget *widget)
+ephy_embed_attach_inspector_cb (WebKitWebInspector *inspector,
+                                EphyEmbed *embed)
 {
-  gtk_widget_show (widget);
+  GtkAllocation allocation;
+  gtk_widget_get_allocation (GTK_WIDGET (embed->priv->scrolled_window), &allocation);
+
+  embed->priv->inspector_attached = TRUE;
+
+  if (embed->priv->paned == NULL)
+  {
+    embed->priv->paned = GTK_PANED (gtk_vpaned_new ());
+    g_object_ref_sink (embed->priv->paned);
+  }
+
+  /* Main view */
+  g_object_ref (embed->priv->scrolled_window);
+  gtk_container_remove (GTK_CONTAINER (embed),
+                        GTK_WIDGET (embed->priv->scrolled_window));
+  gtk_paned_pack1 (embed->priv->paned,
+                   GTK_WIDGET (embed->priv->scrolled_window),
+                   TRUE, FALSE);
+  g_object_unref (embed->priv->scrolled_window);
+
+  /* Set a sane position for the mover */
+  gtk_paned_set_position (embed->priv->paned, allocation.height * 0.5);
+
+  /* The inspector */
+  g_object_ref (embed->priv->inspector_scrolled_window);
+  gtk_container_remove (GTK_CONTAINER (embed->priv->inspector_window),
+                        GTK_WIDGET (embed->priv->inspector_scrolled_window));
+  gtk_paned_pack2 (embed->priv->paned,
+                   GTK_WIDGET (embed->priv->inspector_scrolled_window),
+                   FALSE, TRUE);
+  g_object_unref (embed->priv->inspector_scrolled_window);
+
+  /* Add the paned to the embed, show it, and hide the inspector window */
+  gtk_container_add (GTK_CONTAINER (embed), GTK_WIDGET (embed->priv->paned));
+  gtk_widget_show_all (GTK_WIDGET (embed->priv->paned));
+
+  gtk_widget_hide (embed->priv->inspector_window);
+
+  return TRUE;
+}
+
+static gboolean
+ephy_embed_detach_inspector_cb (WebKitWebInspector *inspector,
+                                EphyEmbed *embed)
+{
+  embed->priv->inspector_attached = FALSE;
+
+  gtk_container_remove (GTK_CONTAINER (embed),
+                        GTK_WIDGET (embed->priv->paned));
+
+  /* Main view */
+  gtk_widget_reparent (GTK_WIDGET (embed->priv->scrolled_window),
+                       GTK_WIDGET (embed));
+
+  /* The inspector */
+  gtk_widget_reparent (GTK_WIDGET (embed->priv->inspector_scrolled_window),
+                       GTK_WIDGET (embed->priv->inspector_window));
+
+  /* Get the view and the inspector back to their places */
+  gtk_widget_destroy (GTK_WIDGET (embed->priv->paned));
+  embed->priv->paned = NULL;
+
+  gtk_widget_show_all (embed->priv->inspector_window);
+  gtk_widget_show_all (embed->priv->inspector_scrolled_window);
+
+  return TRUE;
+}
+
+static gboolean
+ephy_embed_inspect_show_cb (WebKitWebInspector *inspector,
+                            EphyEmbed *embed)
+{
+  if (!embed->priv->inspector_attached)
+    gtk_window_present (GTK_WINDOW (embed->priv->inspector_window));
+
   return TRUE;
 }
 
 static gboolean
 ephy_embed_inspect_close_cb (WebKitWebInspector *inspector,
-                               GtkWidget *widget)
+                             EphyEmbed *embed)
 {
-  gtk_widget_hide (widget);
+  if (!embed->priv->inspector_attached)
+    gtk_widget_hide (embed->priv->inspector_window);
+
   return TRUE;
 }
 
@@ -496,6 +606,7 @@ static const char*
 parse_extension (const char *filename)
 {
   const char *compression;
+  const char *last_separator;
 
   compression = file_is_compressed (filename);
 
@@ -522,7 +633,8 @@ parse_extension (const char *filename)
   }
 
   /* no compression, just look for the last dot in the filename */
-  return g_strrstr (filename, ".");
+  last_separator = strrchr (filename, G_DIR_SEPARATOR);
+  return strrchr ((last_separator) ? last_separator : filename, '.');
 }
 
 static gboolean
@@ -681,7 +793,7 @@ confirm_action_from_mime (WebKitWebView *web_view,
                           DownloadAction action)
 {
   GtkWidget *parent_window;
-  GtkWidget *dialog, *button, *image;
+  GtkWidget *dialog;
   const char *action_label;
   char *mime_description;
   EphyMimePermission mime_permission;
@@ -690,6 +802,9 @@ confirm_action_from_mime (WebKitWebView *web_view,
   int default_response;
   WebKitNetworkResponse *response;
   SoupMessage *message;
+  GtkMessageType mtype;
+  char *title;
+  char *secondary;
 
   parent_window = gtk_widget_get_toplevel (GTK_WIDGET(web_view));
   if (!gtk_widget_is_toplevel (parent_window))
@@ -732,57 +847,48 @@ confirm_action_from_mime (WebKitWebView *web_view,
   suggested_filename = webkit_download_get_suggested_filename (download);
 
   if (mime_permission != EPHY_MIME_PERMISSION_SAFE && helper_app) {
-    dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-                                     _("Download this potentially unsafe file?"));
+    title = _("Download this potentially unsafe file?");
+    mtype = GTK_MESSAGE_WARNING;
+    /* translators: First %s is the file type description, second %s is the
+     * file name */
+    secondary = g_strdup_printf (_("File Type: “%s”.\n\nIt is unsafe to open "
+                                   "“%s” as it could potentially damage your "
+                                   "documents or invade your privacy. "
+                                   "You can download it instead."),
+                                 mime_description, suggested_filename);
 
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              /* translators: First %s is the file type description,
-                                                 Second %s is the file name */
-                                              _("File Type: “%s”.\n\nIt is unsafe to open “%s” as "
-                                                "it could potentially damage your documents or "
-                                                "invade your privacy. You can download it instead."),
-                                              mime_description, suggested_filename);
     action_label = STOCK_DOWNLOAD;
   } else if (action == DOWNLOAD_ACTION_OPEN && helper_app) {
-    dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-                                     _("Open this file?"));
-
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              /* translators: First %s is the file type description,
-                                                 Second %s is the file name,
-                                                 Third %s is the application used to open the file */
-                                              _("File Type: “%s”.\n\nYou can open “%s” using “%s” or save it."),
-                                              mime_description, suggested_filename,
-                                              g_app_info_get_name (helper_app));
+    title = _("Open this file?");
+    mtype = GTK_MESSAGE_QUESTION;
+    /* translators: First %s is the file type description, second %s is the
+     * file name, third %s is the application used to open the file */
+    secondary = g_strdup_printf (_("File Type: “%s”.\n\nYou can open “%s” "
+                                   "using “%s” or save it."),
+                                 mime_description, suggested_filename,
+                                 g_app_info_get_name (helper_app));
   } else  {
-    dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-                                     _("Download this file?"));
-
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              /* translators: First %s is the file type description,
-                                                 Second %s is the file name */
-                                              _("File Type: “%s”.\n\nYou have no application able to open “%s”. "
-                                                "You can download it instead."),
-                                              mime_description, suggested_filename);
+    title = _("Download this file?");
+    mtype = GTK_MESSAGE_QUESTION;
+    /* translators: First %s is the file type description, second %s is the
+     * file name */
+    secondary = g_strdup_printf (_("File Type: “%s”.\n\nYou have no "
+                                   "application able to open “%s”. "
+                                   "You can download it instead."),
+                                 mime_description, suggested_filename);
   }
 
+  dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
+                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                   mtype, GTK_BUTTONS_NONE,
+                                   title);
+  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                            secondary, NULL);
+
   g_free (mime_description);
 
-  button = gtk_button_new_with_mnemonic (_("_Save As..."));
-  image = gtk_image_new_from_stock (GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_image (GTK_BUTTON (button), image);
-  gtk_widget_set_can_default (button, TRUE);
-  /* don't show the image! see bug #307818 */
-  gtk_widget_show (button);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-                                button, DOWNLOAD_ACTION_DOWNLOAD);
-
+  gtk_dialog_add_button (GTK_DIALOG (dialog),
+                         GTK_STOCK_SAVE_AS, DOWNLOAD_ACTION_DOWNLOAD);
   gtk_dialog_add_button (GTK_DIALOG (dialog),
                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   gtk_dialog_add_button (GTK_DIALOG (dialog),
@@ -911,7 +1017,6 @@ ephy_embed_constructed (GObject *object)
   GtkWidget *scrolled_window;
   WebKitWebView *web_view;
   WebKitWebInspector *inspector;
-  GtkWidget *inspector_sw;
 
   embed->priv->top_widgets_vbox = GTK_BOX (gtk_vbox_new (FALSE, 0));
   gtk_box_pack_start (GTK_BOX (embed), GTK_WIDGET (embed->priv->top_widgets_vbox),
@@ -940,16 +1045,16 @@ ephy_embed_constructed (GObject *object)
   embed->priv->inspector_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   inspector = webkit_web_view_get_inspector (web_view);
 
-  inspector_sw = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (inspector_sw),
+  embed->priv->inspector_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (embed->priv->inspector_scrolled_window),
                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_container_add (GTK_CONTAINER (embed->priv->inspector_window),
-                     inspector_sw);
+                     embed->priv->inspector_scrolled_window);
 
   gtk_window_set_title (GTK_WINDOW (embed->priv->inspector_window),
                         _("Web Inspector"));
   gtk_window_set_default_size (GTK_WINDOW (embed->priv->inspector_window),
-                               600, 400);
+                               800, 600);
 
   g_signal_connect (embed->priv->inspector_window,
                     "delete-event", G_CALLBACK (gtk_widget_hide_on_delete),
@@ -957,11 +1062,15 @@ ephy_embed_constructed (GObject *object)
 
   g_object_connect (inspector,
                     "signal::inspect-web-view", G_CALLBACK (ephy_embed_inspect_web_view_cb),
-                    inspector_sw,
+                    embed->priv->inspector_scrolled_window,
                     "signal::show-window", G_CALLBACK (ephy_embed_inspect_show_cb),
-                    embed->priv->inspector_window,
+                    embed,
                     "signal::close-window", G_CALLBACK (ephy_embed_inspect_close_cb),
-                    embed->priv->inspector_window,
+                    embed,
+                    "signal::attach-window", G_CALLBACK (ephy_embed_attach_inspector_cb),
+                    embed,
+                    "signal::detach-window", G_CALLBACK (ephy_embed_detach_inspector_cb),
+                    embed,
                     NULL);
 
   ephy_embed_prefs_add_embed (embed);
@@ -979,6 +1088,7 @@ ephy_embed_init (EphyEmbed *embed)
   embed->priv = EPHY_EMBED_GET_PRIVATE (embed);
 
   embed->priv->scrolled_window = GTK_SCROLLED_WINDOW (gtk_scrolled_window_new (NULL, NULL));
+  embed->priv->paned = NULL;
 
   gtk_scrolled_window_set_policy (embed->priv->scrolled_window,
                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
