@@ -15,9 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmarks-export.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_BOOKMARKS_EXPORT_H
 #define EPHY_BOOKMARKS_EXPORT_H
 
