@@ -17,16 +17,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-notebook.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_NOTEBOOK_H
 #define EPHY_NOTEBOOK_H
 
-#include "ephy-tab.h"
-
 #include <glib.h>
-#include <gtk/gtknotebook.h>
+#include <gtk/gtk.h>
+
+#include "ephy-embed.h"
 
 G_BEGIN_DECLS
 
@@ -55,13 +58,13 @@ struct _EphyNotebookClass
 
 	/* Signals */
 	void	 (* tab_close_req)  (EphyNotebook *notebook,
-				     EphyTab *tab);
+				     EphyEmbed *embed);
 };
 
 GType		ephy_notebook_get_type		(void);
 
 int		ephy_notebook_add_tab		(EphyNotebook *nb,
-						 EphyTab *tab,
+						 EphyEmbed *embed,
 						 int position,
 						 gboolean jump_to);
 	
