@@ -149,43 +149,6 @@ ephy_shell_new_window_cb (EphyEmbedSingle *single,
 		 NULL, NULL, flags, chromemask, is_popup, 0);
 }
 
-
-static gboolean
-ephy_shell_add_sidebar_cb (EphyEmbedSingle *embed_single,
-			   const char *url,
-			   const char *title,
-			   EphyShell *shell)
-{
-	EphySession *session;
-	EphyWindow *window;
-	GtkWidget *dialog;
-
-	session = EPHY_SESSION (ephy_shell_get_session (shell));
-	g_return_val_if_fail (EPHY_IS_SESSION (session), FALSE);
-
-	window = ephy_session_get_active_window (session);
-
-	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_OK,
-					 _("Sidebar extension required"));
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Sidebar Extension Required"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
-
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-		  _("The link you clicked needs the sidebar extension to be "
-		    "installed."));
-
-	g_signal_connect_swapped (dialog, "response", 
-				  G_CALLBACK (gtk_widget_destroy), dialog);
-
-	gtk_widget_show (dialog);
-
-	return TRUE;
-}
-
 #ifdef ENABLE_NETWORK_MANAGER
 
 static void
@@ -223,10 +186,6 @@ impl_get_embed_single (EphyEmbedShell *embed_shell)
 					 G_CALLBACK (ephy_shell_new_window_cb),
 					 shell, G_CONNECT_AFTER);
 
-		g_signal_connect_object (embed_single, "add-sidebar",
-					 G_CALLBACK (ephy_shell_add_sidebar_cb),
-					 shell, G_CONNECT_AFTER);
-
 		priv->embed_single_connected = TRUE;
 
 #ifdef ENABLE_NETWORK_MANAGER
@@ -435,6 +394,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	gboolean open_page = FALSE;
 	gboolean jump_to;
 	gboolean active_is_blank = FALSE;
+	gboolean copy_history = TRUE;
 	GtkWidget *nb;
 	int position = -1;
 	gboolean is_empty = FALSE;
@@ -443,6 +403,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	if (flags & EPHY_NEW_TAB_OPEN_PAGE) open_page = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_NEW_WINDOW) in_new_window = TRUE;
 	if (flags & EPHY_NEW_TAB_IN_EXISTING_WINDOW) in_new_window = FALSE;
+	if (flags & EPHY_NEW_TAB_DONT_COPY_HISTORY) copy_history = FALSE;
 
 	in_new_window = in_new_window && !eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
 	g_return_val_if_fail (open_page == (gboolean)(request != NULL), NULL);
@@ -493,11 +454,11 @@ ephy_shell_new_tab_full (EphyShell *shell,
 		ephy_embed_container_add_child (EPHY_EMBED_CONTAINER (window), embed, position, jump_to);
 	}
 
-	if (previous_embed != NULL)
-	{	
+	if (copy_history && previous_embed != NULL)
+	{
 		ephy_web_view_copy_back_history (ephy_embed_get_web_view (previous_embed),
 						 ephy_embed_get_web_view (embed));
-	}		
+	}
 
 	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
 
