@@ -17,14 +17,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_STATUSBAR_H
 #define EPHY_STATUSBAR_H
 
-#include <gtk/gtkstatusbar.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -43,9 +45,6 @@ struct _EphyStatusbar
 {
         GtkStatusbar parent;
 
-	/*< public >*/
-	GtkTooltips *tooltips;
-
 	/*< private >*/
         EphyStatusbarPrivate *priv;
 };
@@ -62,8 +61,6 @@ GType         ephy_statusbar_get_type			(void);
 
 GtkWidget    *ephy_statusbar_new			(void);
 
-GtkTooltips  *ephy_statusbar_get_tooltips		(EphyStatusbar *statusbar);
-
 GtkWidget    *ephy_statusbar_get_security_frame		(EphyStatusbar *statusbar);
 
 void	      ephy_statusbar_set_caret_mode		(EphyStatusbar *statusbar,
@@ -77,9 +74,6 @@ void          ephy_statusbar_set_popups_state		(EphyStatusbar *statusbar,
 							 gboolean hidden,
 							 const char *tooltip);
 
-void          ephy_statusbar_set_progress		(EphyStatusbar *statusbar,
-							 int progress);
-
 void	      ephy_statusbar_add_widget			(EphyStatusbar *statusbar,
 							 GtkWidget *widget);
 
